"use strict";
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "builderPluginVue", {
  enumerable: true,
  get: function() {
    return builderPluginVue;
  }
});
const _lodash = require("@modern-js/utils/lodash");
const _vueloader = require("vue-loader");
function builderPluginVue(options = {}) {
  return {
    name: "builder-plugin-vue",
    // Remove built-in react plugins.
    // These plugins should be moved to a separate package in the next major version.
    remove: [
      "builder-plugin-react",
      "builder-plugin-antd",
      "builder-plugin-arco"
    ],
    async setup(api) {
      api.modifyBuilderConfig((config, { mergeBuilderConfig }) => {
        return mergeBuilderConfig(config, {
          output: {
            disableSvgr: true
          },
          source: {
            define: {
              // https://link.vuejs.org/feature-flags
              __VUE_OPTIONS_API__: true,
              __VUE_PROD_DEVTOOLS__: false
            }
          },
          tools: {
            babel(_, { addPlugins }) {
              addPlugins([
                [
                  require.resolve("@vue/babel-plugin-jsx"),
                  options.vueJsxOptions || {}
                ]
              ]);
            }
          }
        });
      });
      api.modifyBundlerChain(async (chain, { CHAIN_ID }) => {
        chain.resolve.extensions.add(".vue");
        const vueLoaderOptions = (0, _lodash.merge)({
          compilerOptions: {
            preserveWhitespace: false
          },
          experimentalInlineMatchResource: api.context.bundlerType === "rspack"
        }, options.vueLoaderOptions);
        chain.module.rule(CHAIN_ID.RULE.VUE).test(/\.vue$/).use(CHAIN_ID.USE.VUE).loader(require.resolve("vue-loader")).options(vueLoaderOptions);
        chain.plugin(CHAIN_ID.PLUGIN.VUE_LOADER_PLUGIN).use(_vueloader.VueLoaderPlugin);
      });
    }
  };
}
